@@ -185,7 +185,7 @@ void chop_word(bool forward)
 	 * on the edge of the original line, then put the cursor on that
 	 * edge instead, so that lines will not be joined unexpectedly. */
 	if (!forward) {
-		do_prev_word(ISSET(WORD_BOUNDS));
+		do_prev_word();
 		if (openfile->current != is_current) {
 			if (is_current_x > 0) {
 				openfile->current = is_current;
@@ -194,7 +194,7 @@ void chop_word(bool forward)
 				openfile->current_x = strlen(openfile->current->data);
 		}
 	} else {
-		do_next_word(ISSET(AFTER_ENDS), ISSET(WORD_BOUNDS));
+		do_next_word(ISSET(AFTER_ENDS));
 		if (openfile->current != is_current &&
 							is_current->data[is_current_x] != '\0') {
 			openfile->current = is_current;
@@ -694,9 +694,11 @@ void copy_text(void)
 /* Copy text from the cutbuffer into the current buffer. */
 void paste_text(void)
 {
-#ifndef NANO_TINY
+#if defined(ENABLE_WRAPPING) || !defined(NANO_TINY)
 	/* Remember where the paste started. */
 	linestruct *was_current = openfile->current;
+#endif
+#ifndef NANO_TINY
 	bool had_anchor = was_current->has_anchor;
 #endif
 	ssize_t was_lineno = openfile->current->lineno;
@@ -728,6 +730,12 @@ void paste_text(void)
 	update_undo(PASTE);
 #endif
 
+#ifdef ENABLE_WRAPPING
+	/* When still on the same line and doing hard-wrapping, limit the width. */
+	if (openfile->current == was_current && ISSET(BREAK_LONG_LINES))
+		do_wrap();
+#endif
+
 	/* If we pasted less than a screenful, don't center the cursor. */
 	if (less_than_a_screenful(was_lineno, was_leftedge))
 		focusing = FALSE;
